// Package connections provides handle to connections to external services
package connections

import (
	"fmt"

	gmailparser "gitlab.mashroom.com/mashroom/backend/gmailparser/api"
	offer "gitlab.mashroom.com/mashroom/backend/offer/api"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	address "gitlab.mashroom.com/mashroom/backend/address/api"
	closecom "gitlab.mashroom.com/mashroom/backend/closecom/api"
	document "gitlab.mashroom.com/mashroom/backend/document/api"
	extras "gitlab.mashroom.com/mashroom/backend/extras/api"
	geo "gitlab.mashroom.com/mashroom/backend/geo/api"
	invitation "gitlab.mashroom.com/mashroom/backend/invitation/api"
	invoice "gitlab.mashroom.com/mashroom/backend/invoice/api"
	listing "gitlab.mashroom.com/mashroom/backend/listing/api"
	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	property "gitlab.mashroom.com/mashroom/backend/property/api"
	schedule "gitlab.mashroom.com/mashroom/backend/schedule/api"
	viewing "gitlab.mashroom.com/mashroom/backend/viewing/api"
	zeebe "gitlab.mashroom.com/mashroom/backend/zeebe/api"
)

// Publications related connections
type Publications struct {
	Zoopla    listing.ListingPublicationServiceClient
	Rightmove listing.ListingPublicationServiceClient
	Boomin    listing.ListingPublicationServiceClient
}

// Validate publications connections
func (c *Publications) Validate() error {
	if c.Zoopla == nil {
		return fmt.Errorf("no zoopla client")
	}

	if c.Rightmove == nil {
		return fmt.Errorf("no rightmove client")
	}

	if c.Boomin == nil {
		return fmt.Errorf("no boomin client")
	}

	return nil
}

// Connections remote service connections
type Connections struct {
	Account      account.AccountServiceClient
	Publication  Publications
	Geo          geo.GeoServiceClient
	Document     document.DocumentServiceClient
	Address      address.AddressServiceClient
	Invoice      invoice.InvoiceServiceClient
	Extras       extras.ExtrasServiceClient
	Notification notification.NotificationServiceClient
	Closecom     closecom.ClosecomServiceClient
	Viewing      viewing.ViewingServiceClient
	Offer        offer.OfferServiceClient
	Gmailparser  gmailparser.GmailparserServiceClient
	Property     property.PropertyServiceClient
	Invitation   invitation.InvitationServiceClient
	Schedule     schedule.ScheduleServiceClient
	ZeebeProcess zeebe.ZeebeProcessClient
	SelfRemote   string
}
