package intel

import (
	"bytes"
	"context"
	"encoding/json"
	"io"
	"net/http"

	"gitlab.mashroom.com/mashroom/backend/common/api/grpcerr"
)

type clientImpl struct {
	config Config
}

var (
	errNotImplemented = grpcerr.New(grpcerr.ProviderError, "method not implemented yet")
)

func (client *clientImpl) Avm(ctx context.Context, request *ValuationRequest) (*ValuationResponse, error) {
	response := &ValuationResponse{}

	raw, err := client.makeRequest(ctx, client.config.AvmEndpoint, request, response)
	if err != nil {
		return nil, err
	}

	response.Raw = raw

	return response, nil
}

func (client *clientImpl) Lettings(ctx context.Context, request *ValuationRequest) (*ValuationResponse, error) {
	response := &ValuationResponse{}

	raw, err := client.makeRequest(ctx, client.config.LettingsEndpoint, request, response)
	if err != nil {
		return nil, err
	}

	response.Raw = raw

	return response, nil
}

func (client *clientImpl) Liquidity(ctx context.Context, request *ValuationRequest) (*ValuationResponse, error) {
	// response := &ValuationResponse{}
	// raw, err := client.makeRequest(ctx, client.config.LiquidityEndpoint, request, response)
	// if err != nil {
	// 	return nil, err
	// }
	// response.Raw = raw
	// return response, nil
	return nil, errNotImplemented
}

func (client *clientImpl) makeRequest(
	ctx context.Context,
	endpoint string,
	request *ValuationRequest,
	response interface{},
) (string, error) {
	if request.Location.Building == "" {
		request.Location.Building = "0"
	}

	bs, err := json.Marshal(request)
	if err != nil {
		return "", err
	}

	req, err := http.NewRequestWithContext(ctx, http.MethodPost, endpoint, bytes.NewReader(bs))
	if err != nil {
		return "", err
	}

	req.Header.Set("Content-Type", "application/json")

	resp, err := client.config.Client.Do(req)
	if err != nil {
		return "", err
	}

	defer func() {
		_ = resp.Body.Close()
	}()

	bs, err = io.ReadAll(resp.Body)
	if err != nil {
		return "", err
	}

	_ = json.Unmarshal(bs, response)

	return string(bs), nil
}
