package model

import (
	"database/sql/driver"
	"encoding/json"
	"time"

	geo "gitlab.mashroom.com/mashroom/backend/geo/api"
)

// NearbyPoint represents data model for near-by point.
type NearbyPoint struct {
	ID          string
	Type        geo.PointType
	Name        string
	Description string
	Longitude   float64
	Latitude    float64
	Count       uint64
	Distance    float64
}

// NearbyPointList a list of json-scannable services
type NearbyPointList []*NearbyPoint

// Value returns serialized representation
func (v NearbyPointList) Value() (driver.Value, error) {
	if v == nil {
		return json.Marshal(NearbyPointList{})
	}

	return json.Marshal(v)
}

// Scan parses serialized representation
func (v *NearbyPointList) Scan(value interface{}) error {
	if value == nil {
		return nil
	}

	bs, ok := value.([]byte)
	if !ok {
		return ErrByteArrayAssert
	}

	return json.Unmarshal(bs, v)
}

// NearbyCache represents data model for cache of near-by points.
type NearbyCache struct {
	ID        uint64          `json:"id" db:"id"`
	VersionID uint64          `json:"version_id" db:"version_id"`
	Created   time.Time       `json:"created" db:"created"`
	Stations  NearbyPointList `json:"stations" db:"stations"`
}
