drop table version_publications;

create table version_publications(
  id              bigserial primary key,
  invoice_id      text not null,
  platform        int4 not null,
  listing_id      text not null,
  publication_id  text not null,
  publication_url text not null,
  published_by    text not null,
  unpublished_by  text not null,
  published_at    timestamp not null default now(),
  unpublished_at  timestamp not null,
  expire_at       timestamp not null,
  unique(listing_id, platform)
);

drop table versions;

create table versions(
  id                   bigserial primary key,
  listing_id           text not null,
  property_id          text not null,
  tenancy_id           text not null,
  ivr                  text not null,
  status               int4 not null,
  description          jsonb not null,
  details              jsonb not null,
  people               jsonb not null,
  rental               jsonb not null,
  location             jsonb not null,
  gps                  geography(POINT,4326),
  verification         jsonb not null,
  validation           jsonb not null,
  invitation           jsonb not null,
  viewing_availability jsonb not null,
  valuation            jsonb not null,
  created              timestamp not null default now(),
  updated              timestamp not null default now(),
  migrated_id          text not null default '' -- temporary
);

create index versions_gps on versions using gist(gps);

create view versions_list as select
  id,
  listing_id,
  property_id,
  tenancy_id,
  ivr,
  status,
  description,
  details,
  people,
  rental,
  location,
  valuation,
  verification,
  validation,
  viewing_availability,
  invitation,
  created,
  updated,
  migrated_id,
  (select jsonb_agg(foo.*) from (select * from version_publications where
    version_publications.listing_id = versions.listing_id and platform = 1 order by id asc
  ) foo) as publications_mashroom,
  (select jsonb_agg(foo.*) from (select * from version_publications where
    version_publications.listing_id = versions.listing_id and platform = 2 order by id asc
  ) foo) as publications_rightmove,
  (select jsonb_agg(foo.*) from (select * from version_publications where
    version_publications.listing_id = versions.listing_id and platform = 3 order by id asc
  ) foo) as publications_zoopla,
  coalesce(
    (select published_at from version_publications where
      version_publications.listing_id = versions.listing_id and
      (version_publications.expire_at > now() or version_publications.expire_at = '0001-01-01'::timestamp)
      order by published_at desc limit 1),
    '0001-01-01'::timestamp
  ) as published
from versions;

create table preface_versions(
  id           bigserial primary key,
  client_id    text not null unique,
  description  jsonb not null,
  details      jsonb not null,
  rental       jsonb not null,
  location     jsonb not null,
  gps          geography(POINT, 4326),
  validation   jsonb not null,
  valuation    jsonb not null,
  created      timestamp not null default now(),
  updated      timestamp not null default now(),
  migrated_id text not null default '' -- temporary
);
