drop view versions_list;

alter table versions add column notification jsonb not null default '{}';

update versions set
  notification = jsonb_set(
    notification,
    '{verification_pending}',
    coalesce((verification->'notification'->'verification_pending'), 'false')
);

create view versions_list as
with
maxversion as (
  select
    property_id,
    max(id) as id
  from versions
  group by property_id
),
pubdates as (
  select
    listing_id,
    max(published_at) as published_at
  from version_publications where
    version_publications.unpublished_at <= '1970-01-01'::timestamp
  group by listing_id
),
publications as (
  select * from crosstab(
    $$
    select
      listing_id,
      platform,
      jsonb_agg(version_publications.*) publications
    from version_publications
    group by listing_id, platform
    order by 1,2
    $$,
    $$
    select
      m
    from generate_series(1,4) m
    $$
  ) as (
    listing_id text,
    publications_mashroom jsonb,
    publications_rightmove jsonb,
    publications_zoopla jsonb,
    publications_boomin jsonb
  )
)
select
  versions.*,
  publications_mashroom,
  publications_rightmove,
  publications_zoopla,
  publications_boomin,
  coalesce(pubdates.published_at, '0001-01-01'::timestamp) as published,
  versions.id = maxversion.id as latest
from versions
left join publications on versions.listing_id = publications.listing_id
left join pubdates on pubdates.listing_id = versions.listing_id
left join maxversion on versions.property_id = maxversion.property_id;