drop trigger if exists versions_history_trigger_insert on versions;
drop trigger if exists versions_history_trigger_update on versions;
drop trigger if exists versions_history_trigger on versions;

drop function if exists versions_history_function;
drop function if exists versions_history_function_create;
drop function if exists versions_history_function_update;

drop table if exists versions_history;

create table versions_history(
                                 id                                 bigserial primary key,
                                 version_id                         int8 not null,
                                 "action"                           text not null,
                                 listing_id                         text not null,
                                 property_id                        text not null,
                                 tenancy_id                         text not null,
                                 ivr                                text not null,
                                 status                             int4 not null,
                                 description                        jsonb NOT NULL,
                                 details                            jsonb NOT NULL,
                                 people                             jsonb NOT NULL,
                                 rental                             jsonb NOT NULL,
                                 "location"                         jsonb NOT NULL,
                                 gps public.geography(point, 4326)  NULL,
                                 verification                       jsonb NOT NULL,
                                 validation                         jsonb NOT NULL,
                                 invitation                         jsonb NOT NULL,
                                 viewing_availability               jsonb NOT NULL,
                                 valuation                          jsonb NOT NULL,
                                 created                            timestamp NOT NULL DEFAULT now(),
                                 updated                            timestamp NOT NULL DEFAULT now(),
                                 migrated_id                        text NOT NULL DEFAULT '',
                                 flags                              jsonb NOT NULL DEFAULT '{}',
                                 timezone                           text NOT NULL DEFAULT '',
                                 origin                             jsonb NOT NULL DEFAULT '{}',
                                 notification                       jsonb NOT NULL DEFAULT '{}'
);

create or replace function versions_history_function() returns trigger as $$
begin

    if (TG_OP = 'INSERT') then
        insert into versions_history (version_id, "action", listing_id, property_id, tenancy_id, ivr,
                                      status, description, details, people, rental,
                                      "location", gps, verification, validation, invitation, viewing_availability, valuation, migrated_id,
                                      flags, timezone, origin, notification)
        select
            new.id, 'create', new.listing_id, new.property_id, new.tenancy_id, new.ivr, new.status, new.description, new.details,
            new.people, new.rental, new."location", new.gps, new.verification, new.validation,
            new.invitation, new.viewing_availability, new.valuation,
            new.migrated_id, new.flags, new.timezone, new.origin, new.notification;
        return new;
    elsif (TG_OP = 'UPDATE') then
        insert into versions_history (version_id, "action", listing_id, property_id, tenancy_id, ivr,
                                      status, description, details, people, rental,
                                      "location", gps, verification, validation, invitation, viewing_availability, valuation, migrated_id,
                                      flags, timezone, origin, notification)
        select
            new.id, 'update', new.listing_id, new.property_id, new.tenancy_id, new.ivr, new.status, new.description, new.details,
            new.people, new.rental, new."location", new.gps, new. verification, new.validation,
            new.invitation, new.viewing_availability, new.valuation,
            new.migrated_id, new.flags, new.timezone, new.origin, new.notification;
        return new;
    end if;

end;
$$ language plpgsql;

create trigger versions_history_trigger after insert or update on versions for each row execute procedure versions_history_function();