with offerers as (
  with s as (
    select
      id,
      m.key,
      el.value,
      row_number() over (partition by id, m.key, el.value)
    from versions
    cross join lateral jsonb_each(people->'offerers') m
    cross join lateral jsonb_array_elements(m.value) el
  ),
  h as (
    select
      id,
      key,
      jsonb_agg(value) list
    from s where
      row_number = 1
    group by id, key
  )
  select
    id,
    jsonb_object_agg(key, list) offerers
  from h
  group by id
),
viewers as (
  with s as (
    select
      id,
      m.key,
      el.value,
      row_number() over (partition by id, m.key, el.value)
    from versions
    cross join lateral jsonb_each(people->'viewers') m
    cross join lateral jsonb_array_elements(m.value) el
  ),
  h as (
    select
      id,
      key,
      jsonb_agg(value) list
    from s where
      row_number = 1
    group by id, key
  )
  select
    id,
    jsonb_object_agg(key, list) viewers
  from h
  group by id
),
fixed as (
  select
    versions.id,
    versions.people || jsonb_build_object(
      'viewers', coalesce(viewers, '{}'::jsonb),
      'offerers', coalesce(offerers, '{}'::jsonb)
    ) as people
  from versions
  join offerers on offerers.id = versions.id
  left join viewers on viewers.id = versions.id
)
update versions set
  people = fixed.people
from fixed where
  versions.id = fixed.id;
