package postgres

import (
	"context"

	"github.com/jmoiron/sqlx"
	"gitlab.mashroom.com/mashroom/backend/listing/internal/model"
)

type repositoryVersionNearby struct {
	get    *sqlx.NamedStmt
	insert *sqlx.NamedStmt
}

func prepareVersionNearby(db *sqlx.DB) (stmt repositoryVersionNearby, err error) {
	stmt.get, err = prepareNamed(db, queryGetNearby)
	if err != nil {
		return
	}

	stmt.insert, err = prepareNamed(db, queryInsertNearby)
	if err != nil {
		return
	}

	return
}

const queryGetNearby = `
select
  id,
  version_id,
  created,
  stations
from version_nearby_cache where
  version_id = :version_id
`

func (repo *repositoryVersionNearby) VersionNearbyGet(
	ctx context.Context,
	versionID uint64,
) (m *model.NearbyCache, err error) {
	m = &model.NearbyCache{}

	err = repo.get.GetContext(ctx, m, struct {
		VersionID uint64 `db:"version_id"`
	}{
		VersionID: versionID,
	})
	if err != nil {
		return nil, err
	}

	return
}

const queryInsertNearby = `
insert into version_nearby_cache(
  id,
  version_id,
  created,
  stations
) values (
  default,
  :version_id,
  default,
  :stations
) on conflict (version_id) do update set
  created = now(),
  stations = :stations
returning
  id,
  version_id,
  created,
  stations
`

func (repo *repositoryVersionNearby) VersionNearbyInsert(
	ctx context.Context,
	nearby *model.NearbyCache,
) (err error) {
	err = repo.insert.GetContext(ctx, nearby, nearby)
	if err != nil {
		return
	}

	return
}
