package render

import (
	listing "gitlab.mashroom.com/mashroom/backend/listing/api"
	"gitlab.mashroom.com/mashroom/backend/listing/internal/model"
)

// Validation renderer
func Validation(
	m *model.VersionValidation,
) *listing.Validation {
	return &listing.Validation{
		Valid:      m.Valid,
		Verifiable: m.Verifiable,
		Location: &listing.LocationValidation{
			Postcode: &listing.ValidationItem{
				Errors: m.Location.Postcode,
			},
			Address1: &listing.ValidationItem{
				Errors: m.Location.Address1,
			},
			Address2: &listing.ValidationItem{
				Errors: m.Location.Address2,
			},
			Address3: &listing.ValidationItem{
				Errors: m.Location.Address3,
			},
			Address4: &listing.ValidationItem{
				Errors: m.Location.Address4,
			},
			Flat: &listing.ValidationItem{
				Errors: m.Location.Flat,
			},
			Building: &listing.ValidationItem{
				Errors: m.Location.Building,
			},
			Street: &listing.ValidationItem{
				Errors: m.Location.Street,
			},
			City: &listing.ValidationItem{
				Errors: m.Location.City,
			},
			Gps: &listing.ValidationItem{
				Errors: m.Location.GPS,
			},
			Country: &listing.ValidationItem{
				Errors: m.Location.Country,
			},
			PostTown: &listing.ValidationItem{
				Errors: m.Location.PostTown,
			},
			County: &listing.ValidationItem{
				Errors: m.Location.County,
			},
			AdministrativeCounty: &listing.ValidationItem{
				Errors: m.Location.AdministrativeCounty,
			},
			PostalCounty: &listing.ValidationItem{
				Errors: m.Location.PostalCounty,
			},
			TraditionalCounty: &listing.ValidationItem{
				Errors: m.Location.TraditionalCounty,
			},
			District: &listing.ValidationItem{
				Errors: m.Location.District,
			},
			Address: &listing.ValidationItem{
				Errors: m.Location.Address,
			},
			GeoRegion: &listing.ValidationItem{
				Errors: m.Location.GeoRegion,
			},
			GeoCounty: &listing.ValidationItem{
				Errors: m.Location.GeoCounty,
			},
			GeoTown: &listing.ValidationItem{
				Errors: m.Location.GeoTown,
			},
		},
		Details: &listing.DetailsValidation{
			Type: &listing.ValidationItem{
				Errors: m.Details.Type,
			},
			TypeOther: &listing.ValidationItem{
				Errors: m.Details.TypeOther,
			},
			Area: &listing.ValidationItem{
				Errors: m.Details.Area,
			},
			BedroomsNo: &listing.ValidationItem{
				Errors: m.Details.BedroomsNo,
			},
			BathroomsNo: &listing.ValidationItem{
				Errors: m.Details.BathroomsNo,
			},
			LivingroomsNo: &listing.ValidationItem{
				Errors: m.Details.LivingroomsNo,
			},
			KitchenNo: &listing.ValidationItem{
				Errors: m.Details.KitchenNo,
			},
			AmenityFurniture: &listing.ValidationItem{
				Errors: m.Details.AmenityFurniture,
			},
			AmenityOutsideSpace: &listing.ValidationItem{
				Errors: m.Details.AmenityOutsideSpace,
			},
			AmenityParking: &listing.ValidationItem{
				Errors: m.Details.AmenityParking,
			},
			PetsAllowed: &listing.ValidationItem{
				Errors: m.Details.PetsAllowed,
			},
		},
		Rental: &listing.RentalValidation{
			RentalPrice: &listing.ValidationItem{
				Errors: m.Rental.RentalPrice,
			},
			DssAvailable: &listing.ValidationItem{
				Errors: m.Rental.DssAvailable,
			},
			BillsIncluded: &listing.ValidationItem{
				Errors: m.Rental.BillsIncluded,
			},
			BillsCovered: &listing.ValidationItem{
				Errors: m.Rental.BillsCovered,
			},
			DurationMinMonths: &listing.ValidationItem{
				Errors: m.Rental.DurationMinMonths,
			},
			DurationMaxMonths: &listing.ValidationItem{
				Errors: m.Rental.DurationMaxMonths,
			},
			EarliestMovein: &listing.ValidationItem{
				Errors: m.Rental.EarliestMovein,
			},
			TenancyDepositInsurance: &listing.ValidationItem{
				Errors: m.Rental.TenancyDepositInsurance,
			},
			InventoryReport: &listing.ValidationItem{
				Errors: m.Rental.InventoryReport,
			},
			DepositReplacementFee: &listing.ValidationItem{
				Errors: m.Rental.DepositReplacementFee,
			},
		},
		Description: &listing.DescriptionValidation{
			PostHeadline: &listing.ValidationItem{
				Errors: m.Description.PostHeadline,
			},
			PostPropertyPitch: &listing.ValidationItem{
				Errors: m.Description.PostPropertyPitch,
			},
			PostOuterDescription: &listing.ValidationItem{
				Errors: m.Description.PostOuterDescription,
			},
			PostAreaPitch: &listing.ValidationItem{
				Errors: m.Description.PostAreaPitch,
			},
			PostComment: &listing.ValidationItem{
				Errors: m.Description.PostComment,
			},
			PostAdminPitch: &listing.ValidationItem{
				Errors: m.Description.PostAdminPitch,
			},
			Photos: &listing.ValidationItem{
				Errors: m.Description.Photos,
			},
			Plans: &listing.ValidationItem{
				Errors: m.Description.Plans,
			},
			VideoEmbeds: &listing.ValidationItem{
				Errors: m.Description.VideoEmbeds,
			},
			Tags: &listing.ValidationItem{
				Errors: m.Description.Tags,
			},
		},
		People: &listing.PeopleValidation{
			Manager: &listing.ValidationItem{
				Errors: m.People.Manager,
			},
			Landlord: &listing.ValidationItem{
				Errors: m.People.Landlord,
			},
			Submitter: &listing.ValidationItem{
				Errors: m.People.Submitter,
			},
		},
		Document: &listing.DocumentValidation{
			Epc: &listing.ValidationItem{
				Errors: m.Documents.EPC,
			},
		},
	}
}
