package service

import (
	"context"
	"database/sql"
	"errors"
	"time"

	geo "gitlab.mashroom.com/mashroom/backend/geo/api"
	listing "gitlab.mashroom.com/mashroom/backend/listing/api"
	"gitlab.mashroom.com/mashroom/backend/listing/internal/model"
)

func (srv *serviceImpl) renderNearby(
	ctx context.Context,
	versionID uint64,
	gps *model.GpsCoordinates,
) (resp *listing.Nearby, err error) {
	if gps == nil {
		return nil, nil
	}

	var cache *model.NearbyCache

	cache, err = srv.Repo.VersionNearbyGet(ctx, versionID)
	if err != nil && !errors.Is(err, sql.ErrNoRows) {
		return nil, err
	}

	if cache == nil || time.Since(cache.Created) > time.Hour*24*10 {
		cache, err = srv.refreshNearbyCache(ctx, versionID, gps.Longitude, gps.Latitude)
		if err != nil {
			return nil, err
		}
	}

	var stations []*geo.PointRelative

	for _, s := range cache.Stations {
		stations = append(stations, &geo.PointRelative{
			Point: &geo.Point{
				Id:          s.ID,
				Type:        s.Type,
				Name:        s.Name,
				Description: s.Description,
				Location: &geo.Location{
					Longitude: s.Longitude,
					Latitude:  s.Latitude,
				},
				Count: s.Count,
			},
			Distance: s.Distance,
		})
	}

	return &listing.Nearby{
		Stations: stations,
	}, nil
}
